@@ -15,7 +15,10 @@ dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the re
 
 LogFile="/home/user/MyDocs/SleepAnalyser/SleepAnalyser.log" #Place for log file. IF YOU CHANGE THIS PATH, YOU ALSO HAVE TO CHANGE IT IN /usr/bin/sleepanalyser!
 
-
+translation_copyrights="English, German: George Ruinelli\n"+\
+                                     "Francais: Fred Kwame Ayanfu & Guy Roussil\n"+\
+                                     "Dutch: Fred Kwame Ayanful\n"+\
+                                     "Chinese: "+(u'蒋岚')+" (Peter3316)"
 
 #DEFAULT VALUES
 Yscale_Movement_default=2  #Y stretching of yellow movement bars
