@@ -129,7 +129,7 @@ def ProcessAlarm():
     else: peak=0
     now=Tuple2Seconds(time.localtime())
 #    if(peak>data.Trigger): #big Movement
-    if(peak>(data.Trigger*data.FilterScale*3/40)): #Trigger Alarm
+    if(peak>(data.Trigger*data.Yscale_Sleep_Pattern*3/40)): #Trigger Alarm
        if(records.AlarmIsSet==True and data.AlarmIsActive==False and now>=records.AlarmTimeWindowStart_seconds and now<records.AlarmTimeWindowEnd_seconds):
             #print big movement and we are in alarm time window, update alarm time, set alarm off
             print "************ ALARM ALARM (Movement over trigger level)"
@@ -155,4 +155,4 @@ def ProcessAlarm():
 
 #    print "records.AlarmIsSet", records.AlarmIsSet
 #    print "data.AlarmIsActive:",  data.AlarmIsActive
-#    print ""
+#    print ""
\ No newline at end of file
